==> glabels_1.93.3.orig.tar.gz: glabels-1.93.3/src/view-barcode.h <==
/*
 *  (GLABELS) Label and Business Card Creation program for GNOME
 *
 *  view_barcode.h:  GLabels canvas item wrapper widget
 *
 *  Copyright (C) 2001-2002  Jim Evins <evins@snaught.com>.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

#ifndef __VIEW_BARCODE_H__
#define __VIEW_BARCODE_H__

#include "view-object.h"
#include "label-barcode.h"

G_BEGIN_DECLS


#define GL_TYPE_VIEW_BARCODE            (gl_view_barcode_get_type ())
#define GL_VIEW_BARCODE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GL_TYPE_VIEW_BARCODE, glViewBarcode))
#define GL_VIEW_BARCODE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GL_TYPE_VIEW_BARCODE, glViewBarcodeClass))
#define GL_IS_VIEW_BARCODE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GL_TYPE_VIEW_BARCODE))
#define GL_IS_VIEW_BARCODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GL_TYPE_VIEW_BARCODE))

typedef struct _glViewBarcode          glViewBarcode;
typedef struct _glViewBarcodeClass     glViewBarcodeClass;

typedef struct _glViewBarcodePrivate   glViewBarcodePrivate;

struct _glViewBarcode {
	glViewObject        parent_object;

	glViewBarcodePrivate  *private;
};

struct _glViewBarcodeClass {
	glViewObjectClass   parent_class;
};


extern GType          gl_view_barcode_get_type (void);

extern glViewObject  *gl_view_barcode_new      (glLabelBarcode *object,
						glView     *view);


/* cursor for creating barcode objects */
extern GdkCursor *gl_view_barcode_get_create_cursor (void);

/* event handler for creating barcode objects */
extern gint gl_view_barcode_create_event_handler    (GnomeCanvas *canvas,
						     GdkEvent    *event,
						     glView      *view);

G_END_DECLS

#endif /* __VIEW_BARCODE_H__ */

==> glabels_2.0.2.orig.tar.gz: glabels-2.0.2/src/view-barcode.h <==
/*
 *  (GLABELS) Label and Business Card Creation program for GNOME
 *
 *  view_barcode.h:  GLabels canvas item wrapper widget
 *
 *  Copyright (C) 2001-2002  Jim Evins <evins@snaught.com>.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

#ifndef __VIEW_BARCODE_H__
#define __VIEW_BARCODE_H__

#include "view-object.h"
#include "label-barcode.h"

G_BEGIN_DECLS


#define GL_TYPE_VIEW_BARCODE            (gl_view_barcode_get_type ())
#define GL_VIEW_BARCODE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GL_TYPE_VIEW_BARCODE, glViewBarcode))
#define GL_VIEW_BARCODE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GL_TYPE_VIEW_BARCODE, glViewBarcodeClass))
#define GL_IS_VIEW_BARCODE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GL_TYPE_VIEW_BARCODE))
#define GL_IS_VIEW_BARCODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GL_TYPE_VIEW_BARCODE))

typedef struct _glViewBarcode          glViewBarcode;
typedef struct _glViewBarcodeClass     glViewBarcodeClass;

typedef struct _glViewBarcodePrivate   glViewBarcodePrivate;

struct _glViewBarcode {
	glViewObject        parent_object;

	glViewBarcodePrivate  *private;
};

struct _glViewBarcodeClass {
	glViewObjectClass   parent_class;
};


GType          gl_view_barcode_get_type (void) G_GNUC_CONST;

glViewObject  *gl_view_barcode_new      (glLabelBarcode *object,
					 glView     *view);


/* cursor for creating barcode objects */
GdkCursor *gl_view_barcode_get_create_cursor (void);

/* event handler for creating barcode objects */
gint gl_view_barcode_create_event_handler    (GnomeCanvas *canvas,
					      GdkEvent    *event,
					      glView      *view);

G_END_DECLS

#endif /* __VIEW_BARCODE_H__ */
